# gcodeBuddy

gcodeBuddy is a python library intended to ease the process
of writing to, reading from, and interpreting g-code files, particularly geared towards
3D printer g-code flavors like Marlin.

## Installation

Use the package manager
[pip](https://pip.pypa.io/en/stable/) to install gcodeBuddy.

```bash
pip install gcodeBuddy
```

## View the Documentation with Example Usages

https://gcodebuddy.readthedocs.io/

## Supported G-code Flavors

[Marlin](https://marlinfw.org/meta/gcode/)

## Contributions

Pull requests are more than welcome. For most cases, open
an issue first to discuss what you would like to change.

## License

[MIT](https://choosealicense.com/licenses/mit/)
